@@ -22,10 +22,16 @@ declarative way.
 from types import FunctionType
 from inspect import getargspec, getdoc
 
-from gajim.command_system.dispatcher import Host, Container
-from gajim.command_system.dispatcher import get_command, list_commands
-from gajim.command_system.mapping import parse_arguments, adapt_arguments
-from gajim.command_system.errors import DefinitionError, CommandError, NoCommandError
+from gajim.command_system.dispatcher import Host
+from gajim.command_system.dispatcher import Container
+from gajim.command_system.dispatcher import get_command
+from gajim.command_system.dispatcher import list_commands
+from gajim.command_system.mapping import parse_arguments
+from gajim.command_system.mapping import adapt_arguments
+from gajim.command_system.errors import DefinitionError
+from gajim.command_system.errors import CommandError
+from gajim.command_system.errors import NoCommandError
+
 
 class CommandHost(metaclass=Host):
     """
@@ -39,10 +45,11 @@ class CommandHost(metaclass=Host):
     """
     __metaclass__ = Host
 
+
 class CommandContainer(metaclass=Container):
     """
     Command container is an entity which holds defined commands,
-    allowing them to be dispatched and proccessed correctly. Each
+    allowing them to be dispatched and processed correctly. Each
     command container may be bound to a one or more command hosts.
 
     The AUTOMATIC class variable, which must be defined by a command
@@ -55,7 +62,8 @@ class CommandContainer(metaclass=Container):
     """
     __metaclass__ = Container
 
-class CommandProcessor(object):
+
+class CommandProcessor:
     """
     Command processor is an immediate command emitter. It does not
     participate in the dispatching process directly, but must define a
@@ -75,6 +83,7 @@ class CommandProcessor(object):
         Try to process text as a command. Returns True if it has been
         processed as a command and False otherwise.
         """
+        # pylint: disable=assignment-from-no-return
         prefix = text.startswith(self.COMMAND_PREFIX)
         length = len(text) > len(self.COMMAND_PREFIX)
         if not (prefix and length):
@@ -95,17 +104,17 @@ class CommandProcessor(object):
         return True
 
     def execute_command(self, name, arguments):
-        command = self.get_command(name)
+        cmd = self.get_command(name)
 
         args, opts = parse_arguments(arguments) if arguments else ([], [])
-        args, kwargs = adapt_arguments(command, arguments, args, opts)
+        args, kwargs = adapt_arguments(cmd, arguments, args, opts)
 
-        if self.command_preprocessor(command, name, arguments, args, kwargs):
+        if self.command_preprocessor(cmd, name, arguments, args, kwargs):
             return
-        value = command(self, *args, **kwargs)
-        self.command_postprocessor(command, name, arguments, args, kwargs, value)
+        value = cmd(self, *args, **kwargs)
+        self.command_postprocessor(cmd, name, arguments, args, kwargs, value)
 
-    def command_preprocessor(self, command, name, arguments, args, kwargs):
+    def command_preprocessor(self, cmd, name, arguments, args, kwargs):
         """
         Redefine this method in the subclass to execute custom code
         before command gets executed.
@@ -113,14 +122,12 @@ class CommandProcessor(object):
         If returns True then command execution will be interrupted and
         command will not be executed.
         """
-        pass
 
-    def command_postprocessor(self, command, name, arguments, args, kwargs, value):
+    def command_postprocessor(self, cmd, name, arguments, args, kwargs, value):
         """
         Redefine this method in the subclass to execute custom code
         after command gets executed.
         """
-        pass
 
     def looks_like_command(self, text, body, name, arguments):
         """
@@ -131,20 +138,20 @@ class CommandProcessor(object):
         be interrupted and that value will be used to return from
         process_as_command.
         """
-        pass
 
     def get_command(self, name):
-        command = get_command(self.COMMAND_HOST, name)
-        if not command:
+        cmd = get_command(self.COMMAND_HOST, name)
+        if not cmd:
             raise NoCommandError("Command does not exist", name=name)
-        return command
+        return cmd
 
     def list_commands(self):
         commands = list_commands(self.COMMAND_HOST)
         commands = dict(commands)
-        return sorted(list(commands.values()), key=lambda k: k.__repr__())
+        return sorted(set(commands.values()), key=lambda k: k.__repr__())
 
-class Command(object):
+
+class Command:
 
     def __init__(self, handler, *names, **properties):
         self.handler = handler
@@ -159,7 +166,7 @@ class Command(object):
         try:
             return self.handler(*args, **kwargs)
 
-        # This allows to use a shortcuted way of raising an exception
+        # This allows to use a shortcut way of raising an exception
         # inside a handler. That is to raise a CommandError without
         # command or name attributes set. They will be set to a
         # corresponding values right here in case if they was not set by
@@ -214,12 +221,13 @@ class Command(object):
         Extract handler's arguments specification, as it was defined
         preserving their order.
         """
-        names, var_args, var_kwargs, defaults = getargspec(self.handler)
+        names, var_args, var_kwargs, defaults = getargspec(self.handler)  # pylint: disable=W1505
 
         # Behavior of this code need to be checked. Might yield
         # incorrect results on some rare occasions.
         spec_args = names[:-len(defaults) if defaults else len(names)]
-        spec_kwargs = list(zip(names[-len(defaults):], defaults)) if defaults else {}
+        spec_kwargs = list(
+            zip(names[-len(defaults):], defaults)) if defaults else {}
 
         # Removing self from arguments specification. Command handler
         # should receive the processors as a first argument, which
@@ -229,13 +237,14 @@ class Command(object):
 
         return spec_args, spec_kwargs, var_args, var_kwargs
 
+
 def command(*names, **properties):
     """
     A decorator for defining commands in a declarative way. Provides
     facilities for setting command's names and properties.
 
     Names should contain a set of names (aliases) by which the command
-    can be reached. If no names are given - the the native name (the one
+    can be reached. If no names are given - the native name (the one
     extracted from the command handler) will be used.
 
     If native=True is given (default) and names is non-empty - then the
@@ -289,7 +298,8 @@ def command(*names, **properties):
         raise DefinitionError("Empty option can be used only with raw commands")
 
     if extra and overlap:
-        raise DefinitionError("Extra and overlap options can not be used together")
+        raise DefinitionError("Extra and overlap options can not be used "
+                              "together")
 
     properties = {
         'usage': usage,
@@ -306,16 +316,16 @@ def command(*names, **properties):
         Decorator which receives handler as a first argument and then
         wraps it in the command which then returns back.
         """
-        command = Command(handler, *names, **properties)
+        cmd = Command(handler, *names, **properties)
 
         # Extract and inject a native name if either no other names are
         # specified or native property is enabled, while making
         # sure it is going to be the first one in the list.
         if not names or native:
-            names.insert(0, command.native_name)
-            command.names = tuple(names)
+            names.insert(0, cmd.native_name)
+            cmd.names = tuple(names)
 
-        return command
+        return cmd
 
     # Workaround if we are getting called without parameters. Keep in
     # mind that in that case - first item in the names will be the
@@ -325,6 +335,7 @@ def command(*names, **properties):
 
     return decorator
 
+
 def doc(text):
     """
     This decorator is used to bind a documentation (a help) to a
