@@ -140,13 +140,16 @@ _dependencies = {
     'AV': False,
     'GEOCLUE': False,
     'UPNP': False,
-    'PYCURL': False,
     'GSOUND': False,
     'GSPELL': False,
     'IDLE': False,
 }
 
 
+def print_version():
+    log('gajim').info('Gajim Version: %s', gajim.__version__)
+
+
 def get_client(account):
     return connections[account]
 
@@ -239,13 +242,6 @@ def detect_dependencies():
     except ValueError:
         pass
 
-    # PYCURL
-    try:
-        import pycurl  # pylint: disable=unused-import
-        _dependencies['PYCURL'] = True
-    except ImportError:
-        pass
-
     # IDLE
     try:
         from gajim.common import idle
@@ -386,6 +382,13 @@ def get_number_of_connected_accounts(accounts_list=None):
             connected_accounts = connected_accounts + 1
     return connected_accounts
 
+def get_available_clients():
+    clients = []
+    for client in connections.values():
+        if client.state.is_available:
+            clients.append(client)
+    return clients
+
 def get_connected_accounts(exclude_local=False):
     """
     Returns a list of CONNECTED accounts
@@ -404,8 +407,9 @@ def get_accounts_sorted():
     '''
     account_list = config.get_per('accounts')
     account_list.sort(key=str.lower)
-    account_list.remove('Local')
-    account_list.insert(0, 'Local')
+    if 'Local' in account_list:
+        account_list.remove('Local')
+        account_list.insert(0, 'Local')
     return account_list
 
 def get_enabled_accounts_with_labels(exclude_local=True, connected_only=False,
