@@ -25,7 +25,7 @@
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 try:
-    from gajim.common import caps_cache
+    from gajim.common import app
     from gajim.common.i18n import _
     from gajim.common.account import Account
     from gajim import common
@@ -46,17 +46,16 @@ class XMPPEntity:
 
 class CommonContact(XMPPEntity):
 
-    def __init__(self, jid, account, resource, show, status, name,
-                 chatstate, client_caps=None):
+    def __init__(self, jid, account, resource, show, presence, status, name,
+                 chatstate):
 
         XMPPEntity.__init__(self, jid, account, resource)
 
-        self.show = show
+        self._show = show
+        self._presence = presence
         self.status = status
         self.name = name
 
-        self.client_caps = client_caps or caps_cache.NullClientCaps()
-
         # this is contact's chatstate
         self._chatstate = chatstate
 
@@ -68,10 +67,20 @@ class CommonContact(XMPPEntity):
 
     @show.setter
     def show(self, value):
-        if not isinstance(value, str):
-            raise TypeError('show must be a string')
         self._show = value
 
+    @property
+    def presence(self):
+        return self._presence
+
+    @presence.setter
+    def presence(self, value):
+        self._presence = value
+
+    @property
+    def is_available(self):
+        return self._presence.is_available
+
     @property
     def chatstate_enum(self):
         return self._chatstate
@@ -97,6 +106,10 @@ class CommonContact(XMPPEntity):
     def is_pm_contact(self):
         return self._is_pm_contact
 
+    @property
+    def is_groupchat(self):
+        return False
+
     def get_full_jid(self):
         raise NotImplementedError
 
@@ -111,14 +124,23 @@ class CommonContact(XMPPEntity):
         if self.show == 'offline':
             # Unfortunately, if all resources are offline, the contact
             # includes the last resource that was online. Check for its
-            # show, so we can be sure it's existant. Otherwise, we still
+            # show, so we can be sure it's existent. Otherwise, we still
             # return caps for a contact that has no resources left.
             return False
-        return caps_cache.client_supports(self.client_caps, requested_feature)
+
+        disco_info = app.logger.get_last_disco_info(self.get_full_jid())
+        if disco_info is None:
+            return False
+
+        return disco_info.supports(requested_feature)
 
     @property
     def uses_phone(self):
-        return caps_cache.get_client_identity(self.client_caps) == 'phone'
+        disco_info = app.logger.get_last_disco_info(self.get_full_jid())
+        if disco_info is None:
+            return False
+
+        return disco_info.has_category('phone')
 
 
 class Contact(CommonContact):
@@ -126,7 +148,7 @@ class Contact(CommonContact):
     Information concerning a contact
     """
     def __init__(self, jid, account, name='', groups=None, show='', status='',
-    sub='', ask='', resource='', priority=0, keyID='', client_caps=None,
+    sub='', ask='', resource='', priority=0,
     chatstate=None, idle_time=None, avatar_sha=None, groupchat=False,
     is_pm_contact=False):
         if not isinstance(jid, str):
@@ -134,10 +156,10 @@ class Contact(CommonContact):
         if groups is None:
             groups = []
 
-        CommonContact.__init__(self, jid, account, resource, show, status, name,
-                               chatstate, client_caps=client_caps)
+        CommonContact.__init__(self, jid, account, resource, show,
+                               None, status, name, chatstate)
 
-        self.contact_name = '' # nick choosen by contact
+        self.contact_name = '' # nick chosen by contact
         self.groups = [i if i else _('General') for i in set(groups)] # filter duplicate values
         self.avatar_sha = avatar_sha
         self._is_groupchat = groupchat
@@ -147,7 +169,6 @@ class Contact(CommonContact):
         self.ask = ask
 
         self.priority = priority
-        self.keyID = keyID
         self.idle_time = idle_time
 
         self.pep = {}
@@ -158,17 +179,24 @@ class Contact(CommonContact):
         return self.jid
 
     def get_shown_name(self):
+        if self._is_groupchat:
+            return self._get_groupchat_name()
         if self.name:
             return self.name
         if self.contact_name:
             return self.contact_name
         return self.jid.split('@')[0]
 
+    def _get_groupchat_name(self):
+        from gajim.common.helpers import get_groupchat_name
+        con = app.connections[self.account.name]
+        return get_groupchat_name(con, self.jid)
+
     def get_shown_groups(self):
         if self.is_observer():
             return [_('Observers')]
-        if self.is_groupchat():
-            return [_('Groupchats')]
+        if self.is_groupchat:
+            return [_('Group chats')]
         if self.is_transport():
             return [_('Transports')]
         if not self.groups:
@@ -188,7 +216,7 @@ class Contact(CommonContact):
             return False
         if self.sub in ('none', 'from') and (self.name or self.groups):
             return False
-        if _('Not in Roster') in self.groups:
+        if _('Not in contact list') in self.groups:
             return False
         return True
 
@@ -200,24 +228,41 @@ class Contact(CommonContact):
             is_observer = True
         return is_observer
 
+    @property
     def is_groupchat(self):
         return self._is_groupchat
 
+    @property
+    def is_connected(self):
+        try:
+            return app.gc_connected[self.account.name][self.jid]
+        except Exception:
+            return False
+
     def is_transport(self):
         # if not '@' or '@' starts the jid then contact is transport
         return self.jid.find('@') <= 0
 
+    def can_notify(self):
+        if not self.is_groupchat:
+            raise ValueError
+
+        all_ = app.config.get('notify_on_all_muc_messages')
+        room = app.config.get_per('rooms', self.jid, 'notify_on_all_messages')
+        return all_ or room
+
 
 class GC_Contact(CommonContact):
     """
     Information concerning each groupchat contact
     """
 
-    def __init__(self, room_jid, account, name='', show='', status='', role='',
-    affiliation='', jid='', resource='', chatstate=None, avatar_sha=None):
+    def __init__(self, room_jid, account, name='', show='', presence=None,
+                 status='', role='', affiliation='', jid='', resource='',
+                 chatstate=None, avatar_sha=None):
 
-        CommonContact.__init__(self, jid, account, resource, show, status, name,
-                               chatstate)
+        CommonContact.__init__(self, jid, account, resource, show,
+                               presence, status, name, chatstate)
 
         self.room_jid = room_jid
         self.role = role
@@ -231,7 +276,7 @@ class GC_Contact(CommonContact):
         return self.name
 
     def get_avatar(self, *args, **kwargs):
-        return common.app.interface.get_avatar(self.avatar_sha, *args, **kwargs)
+        return common.app.interface.get_avatar(self, *args, **kwargs)
 
     def as_contact(self):
         """
@@ -239,7 +284,7 @@ class GC_Contact(CommonContact):
         """
         return Contact(jid=self.get_full_jid(), account=self.account,
             name=self.name, groups=[], show=self.show, status=self.status,
-            sub='none', client_caps=self.client_caps, avatar_sha=self.avatar_sha,
+            sub='none', avatar_sha=self.avatar_sha,
             is_pm_contact=True)
 
 
@@ -261,13 +306,6 @@ class LegacyContactsAPI:
         self._metacontact_manager = MetacontactManager(self)
         self._accounts = {}
 
-    def change_account_name(self, old_name, new_name):
-        self._accounts[new_name] = self._accounts[old_name]
-        self._accounts[new_name].name = new_name
-        del self._accounts[old_name]
-
-        self._metacontact_manager.change_account_name(old_name, new_name)
-
     def add_account(self, account_name):
         self._accounts[account_name] = Account(account_name, Contacts(),
                 GC_Contacts())
@@ -285,8 +323,8 @@ class LegacyContactsAPI:
         self._metacontact_manager.remove_account(account)
 
     def create_contact(self, jid, account, name='', groups=None, show='',
-    status='', sub='', ask='', resource='', priority=0, keyID='',
-    client_caps=None, chatstate=None, idle_time=None,
+    status='', sub='', ask='', resource='', priority=0,
+    chatstate=None, idle_time=None,
     avatar_sha=None, groupchat=False):
         if groups is None:
             groups = []
@@ -294,36 +332,35 @@ class LegacyContactsAPI:
         account = self._accounts.get(account, account)
         return Contact(jid=jid, account=account, name=name, groups=groups,
             show=show, status=status, sub=sub, ask=ask, resource=resource,
-            priority=priority, keyID=keyID, client_caps=client_caps,
+            priority=priority,
             chatstate=chatstate, idle_time=idle_time, avatar_sha=avatar_sha,
             groupchat=groupchat)
 
     def create_self_contact(self, jid, account, resource, show, status, priority,
-    name='', keyID=''):
+    name=''):
         conn = common.app.connections[account]
         nick = name or common.app.nicks[account]
         account = self._accounts.get(account, account) # Use Account object if available
         self_contact = self.create_contact(jid=jid, account=account,
                 name=nick, groups=['self_contact'], show=show, status=status,
-                sub='both', ask='none', priority=priority, keyID=keyID,
+                sub='both', ask='none', priority=priority,
                 resource=resource)
         self_contact.pep = conn.pep
         return self_contact
 
     def create_not_in_roster_contact(self, jid, account, resource='', name='',
-    keyID=''):
+                                     groupchat=False):
         # Use Account object if available
         account = self._accounts.get(account, account)
         return self.create_contact(jid=jid, account=account, resource=resource,
-            name=name, groups=[_('Not in Roster')], show='not in roster',
-            status='', sub='none', keyID=keyID)
+            name=name, groups=[_('Not in contact list')], show='not in roster',
+            status='', sub='none', groupchat=groupchat)
 
     def copy_contact(self, contact):
         return self.create_contact(contact.jid, contact.account,
             name=contact.name, groups=contact.groups, show=contact.show,
             status=contact.status, sub=contact.sub, ask=contact.ask,
             resource=contact.resource, priority=contact.priority,
-            keyID=contact.keyID, client_caps=contact.client_caps,
             chatstate=contact.chatstate_enum,
             idle_time=contact.idle_time, avatar_sha=contact.avatar_sha)
 
@@ -351,6 +388,9 @@ class LegacyContactsAPI:
     def get_contact(self, account, jid, resource=None):
         return self._accounts[account].contacts.get_contact(jid, resource=resource)
 
+    def get_contact_strict(self, account, jid, resource):
+        return self._accounts[account].contacts.get_contact_strict(jid, resource)
+
     def get_avatar(self, account, *args, **kwargs):
         return self._accounts[account].contacts.get_avatar(*args, **kwargs)
 
@@ -424,7 +464,7 @@ class LegacyContactsAPI:
                     # count metacontacts only once
                     continue
                 contact = self._accounts[account].contacts._contacts[jid][0]
-                if _('Not in roster') in contact.groups:
+                if _('Not in contact list') in contact.groups:
                     continue
                 in_groups = False
                 if groups == []:
@@ -447,11 +487,12 @@ class LegacyContactsAPI:
             return getattr(self._metacontact_manager, attr_name)
         raise AttributeError(attr_name)
 
-    def create_gc_contact(self, room_jid, account, name='', show='', status='',
-            role='', affiliation='', jid='', resource='', avatar_sha=None):
+    def create_gc_contact(self, room_jid, account, name='', show='',
+                          presence=None, status='', role='',
+                          affiliation='', jid='', resource='', avatar_sha=None):
         account = self._accounts.get(account, account) # Use Account object if available
-        return GC_Contact(room_jid, account, name, show, status, role, affiliation, jid,
-                resource, avatar_sha=avatar_sha)
+        return GC_Contact(room_jid, account, name, show, presence, status,
+                          role, affiliation, jid, resource, avatar_sha=avatar_sha)
 
     def add_gc_contact(self, account, gc_contact):
         return self._accounts[account].gc_contacts.add_gc_contact(gc_contact)
@@ -468,6 +509,9 @@ class LegacyContactsAPI:
     def get_nick_list(self, account, room_jid):
         return self._accounts[account].gc_contacts.get_nick_list(room_jid)
 
+    def get_gc_contact_list(self, account, room_jid):
+        return self._accounts[account].gc_contacts.get_gc_contact_list(room_jid)
+
     def get_gc_contact(self, account, room_jid, nick):
         return self._accounts[account].gc_contacts.get_gc_contact(room_jid, nick)
 
@@ -497,7 +541,7 @@ class Contacts():
         self._contacts = {}
 
     def add_contact(self, contact):
-        if contact.jid not in self._contacts or contact.is_groupchat():
+        if contact.jid not in self._contacts or contact.is_groupchat:
             self._contacts[contact.jid] = [contact]
             return
         contacts = self._contacts[contact.jid]
@@ -532,13 +576,13 @@ class Contacts():
         """
         Return the list of contact instances for this jid
         """
-        return self._contacts.get(jid, [])
+        return list(self._contacts.get(jid, []))
 
     def get_contact(self, jid, resource=None):
         ### WARNING ###
         # This function returns a *RANDOM* resource if resource = None!
         # Do *NOT* use if you need to get the contact to which you
-        # send a message for example, as a bare JID in Jabber means
+        # send a message for example, as a bare JID in XMPP means
         # highest available resource, which this function ignores!
         """
         Return the contact instance for the given resource if it's given else the
@@ -564,18 +608,16 @@ class Contacts():
     def get_groupchat_contact(self, jid):
         if jid in self._contacts:
             contacts = self._contacts[jid]
-            if contacts[0].is_groupchat():
+            if contacts[0].is_groupchat:
                 return contacts[0]
 
-    def get_avatar(self, jid, size=None, scale=None):
+    def get_avatar(self, jid, size, scale, show=None):
         if jid not in self._contacts:
             return None
 
         for resource in self._contacts[jid]:
-            if resource.avatar_sha is None:
-                continue
             avatar = common.app.interface.get_avatar(
-                resource.avatar_sha, size, scale)
+                resource, size, scale, show)
             if avatar is None:
                 self.set_avatar(jid, None)
             return avatar
@@ -605,7 +647,7 @@ class Contacts():
 
     def get_contacts_jid_list(self):
         return [jid for jid, contact in self._contacts.items() if not
-                contact[0].is_groupchat()]
+                contact[0].is_groupchat]
 
     def get_contact_from_full_jid(self, fjid):
         """
@@ -636,7 +678,7 @@ class Contacts():
         for _contact in self._contacts[old_jid]:
             _contact.jid = new_jid
             self._contacts[new_jid].append(_contact)
-            del self._contacts[old_jid]
+        del self._contacts[old_jid]
 
     def get_combined_chatstate(self, jid):
         if jid not in self._contacts:
@@ -686,6 +728,12 @@ class GC_Contacts():
             return []
         return list(self._rooms[room_jid].keys())
 
+    def get_gc_contact_list(self, room_jid):
+        try:
+            return list(self._rooms[room_jid].values())
+        except Exception:
+            return []
+
     def get_gc_contact(self, room_jid, nick):
         try:
             return self._rooms[room_jid][nick]
@@ -728,10 +776,6 @@ class MetacontactManager():
         self._metacontacts_tags = {}
         self._contacts = contacts
 
-    def change_account_name(self, old_name, new_name):
-        self._metacontacts_tags[new_name] = self._metacontacts_tags[old_name]
-        del self._metacontacts_tags[old_name]
-
     def add_account(self, account):
         if account not in self._metacontacts_tags:
             self._metacontacts_tags[account] = {}
@@ -864,7 +908,7 @@ class MetacontactManager():
         Data is {'jid': jid, 'account': account, 'order': order} order is
         optional
         """
-        show_list = ['not in roster', 'error', 'offline', 'invisible', 'dnd',
+        show_list = ['not in roster', 'error', 'offline', 'dnd',
                      'xa', 'away', 'chat', 'online', 'requested', 'message']
 
         jid = data['jid']
