@@ -540,7 +540,7 @@ class MUC(BaseModule):
             return
 
         if (not app.config.get('log_contact_status_changes') or
-                not app.config.should_log(self._account, properties.jid)):
+                not helpers.should_log(self._account, properties.jid)):
             return
 
         additional_data = AdditionalDataDict()
@@ -818,6 +818,10 @@ class MUCManager:
     def get_mucs_with_state(self, states):
         return [muc for muc in self._mucs.values() if muc.state in states]
 
+    def reset_state(self):
+        for muc in self._mucs.values():
+            self.set_state(muc.jid, MUCJoinedState.NOT_JOINED)
+
     def __contains__(self, room_jid):
         return room_jid in self._mucs
 
