@@ -26,7 +26,7 @@ from packaging.version import Version as V
 
 from gajim.common import i18n
 
-_MIN_NBXMPP_VER = '1.0.1'
+_MIN_NBXMPP_VER = '1.0.2'
 _MIN_GTK_VER = '3.22.27'
 _MIN_CAIRO_VER = '1.16.0'
 _MIN_PYGOBJECT_VER = '3.32.0'
@@ -94,7 +94,7 @@ def _disable_csd():
     if sys.platform != 'win32':
         return
 
-    if 'GTK_OSD' in os.environ:
+    if 'GTK_CSD' in os.environ:
         # Respect user settings
         return
 
