@@ -14,6 +14,7 @@
 
 import logging
 import os
+import sys
 
 from gi.repository import GLib
 from gi.repository import Gtk
@@ -28,7 +29,6 @@ except Exception:
 from gajim.common import app
 from gajim.common import configpaths
 from gajim.common import helpers
-from gajim.common import config as c_config
 from gajim.common import idle
 from gajim.common.nec import NetworkEvent
 from gajim.common.i18n import _
@@ -68,20 +68,12 @@ class Preferences(Gtk.ApplicationWindow):
         ### General tab ###
         ## Behavior of Windows and Tabs
         # Set default for single window type
-        choices = c_config.opt_one_window_types
-        type_ = app.config.get('one_message_window')
-        if type_ in choices:
-            self._ui.one_window_type_combobox.set_active(choices.index(type_))
-        else:
-            self._ui.one_window_type_combobox.set_active(0)
+        self._ui.one_window_type_combobox.set_active_id(
+            app.config.get('one_message_window'))
 
         # Show roster on startup
-        choices = c_config.opt_show_roster_on_startup
-        type_ = app.config.get('show_roster_on_startup')
-        if type_ in choices:
-            self._ui.show_roster_on_startup.set_active(choices.index(type_))
-        else:
-            self._ui.show_roster_on_startup.set_active(0)
+        self._ui.show_roster_on_startup.set_active_id(
+            app.config.get('show_roster_on_startup'))
 
         # Quit on roster x
         st = app.config.get('quit_on_roster_x_button')
@@ -160,7 +152,8 @@ class Preferences(Gtk.ApplicationWindow):
 
         # Group chat settings
         threshold_model = self._ui.sync_threshold_combobox.get_model()
-        days = app.config.get_options('threshold_options', return_type=int)
+        options = app.config.get('threshold_options').split(',')
+        days = [int(option.strip()) for option in options]
         for day in days:
             if day == 0:
                 label = _('No threshold')
@@ -175,7 +168,7 @@ class Preferences(Gtk.ApplicationWindow):
         self._ui.join_leave_checkbutton.set_active(st)
 
         st = app.config.get('print_status_muc_default')
-        self._ui.status_change_checkbutton.set_active(st)
+        self._ui.show_status_change_checkbutton.set_active(st)
 
         # Displayed chat state notifications
         st = app.config.get('show_chatstate_in_tabs')
@@ -273,23 +266,11 @@ class Preferences(Gtk.ApplicationWindow):
 
         # Ask for status when online/offline
         st = app.config.get('ask_online_status')
-        self._ui.prompt_online_status_message_checkbutton.set_active(st)
+        self._ui.sign_in_status_checkbutton.set_active(st)
         st = app.config.get('ask_offline_status')
-        self._ui.prompt_offline_status_message_checkbutton.set_active(st)
-
-        # Default status messages
-        self.fill_default_msg_treeview()
-
-        # Status messages
-        renderer = Gtk.CellRendererText()
-        renderer.connect('edited', self.on_msg_cell_edited)
-        renderer.set_property('editable', True)
-        col = Gtk.TreeViewColumn('name', renderer, text=0)
-        self._ui.msg_treeview.append_column(col)
-        self.fill_msg_treeview()
-
-        buf = self._ui.msg_textview.get_buffer()
-        buf.connect('end-user-action', self.on_msg_textview_changed)
+        self._ui.sign_out_status_checkbutton.set_active(st)
+        st = app.config.get('always_ask_for_status_message')
+        self._ui.status_change_checkbutton.set_active(st)
 
         ### Style tab ###
         # Themes
@@ -423,19 +404,20 @@ class Preferences(Gtk.ApplicationWindow):
         st = app.config.get('log_contact_status_changes')
         self._ui.log_show_changes_checkbutton.set_active(st)
 
+        st = app.config.get('use_keyring')
+        self._ui.use_keyring_checkbutton.set_active(st)
+
         self._ui.enable_logging.set_active(app.get_debug_mode())
         self._ui.enable_logging.show()
 
+        if sys.platform in ('win32', 'darwin'):
+            st = app.config.get('check_for_update')
+            self._ui.update_check.set_active(st)
+            self._ui.update_check.show()
+
         self._ui.connect_signals(self)
         self.connect('key-press-event', self._on_key_press)
 
-        self._ui.msg_treeview.get_model().connect('row-changed',
-                                self.on_msg_treemodel_row_changed)
-        self._ui.msg_treeview.get_model().connect('row-deleted',
-                                self.on_msg_treemodel_row_deleted)
-        self._ui.default_msg_treeview.get_model().connect('row-changed',
-                                self.on_default_msg_treemodel_row_changed)
-
         self.sounds_preferences = None
         self.theme_preferences = None
 
@@ -494,16 +476,12 @@ class Preferences(Gtk.ApplicationWindow):
                 yield ctrl
 
     ### General tab ###
-    def on_one_window_type_combo_changed(self, widget):
-        active = widget.get_active()
-        config_type = c_config.opt_one_window_types[active]
-        app.config.set('one_message_window', config_type)
+    def on_one_window_type_combo_changed(self, combobox):
+        app.config.set('one_message_window', combobox.get_active_id())
         app.interface.msg_win_mgr.reconfig()
 
-    def on_show_roster_on_startup_changed(self, widget):
-        active = widget.get_active()
-        config_type = c_config.opt_show_roster_on_startup[active]
-        app.config.set('show_roster_on_startup', config_type)
+    def on_show_roster_on_startup_changed(self, combobox):
+        app.config.set('show_roster_on_startup', combobox.get_active_id())
 
     def on_quit_on_roster_x_checkbutton_toggled(self, widget):
         self.on_checkbutton_toggled(widget, 'quit_on_roster_x_button')
@@ -592,7 +570,7 @@ class Preferences(Gtk.ApplicationWindow):
         for control in self._get_all_muc_controls():
             control.update_actions()
 
-    def _on_status_change_toggled(self, widget):
+    def _on_show_status_change_toggled(self, widget):
         self.on_checkbutton_toggled(widget, 'print_status_muc_default')
         for control in self._get_all_muc_controls():
             control.update_actions()
@@ -689,148 +667,14 @@ class Preferences(Gtk.ApplicationWindow):
         widget.set_inconsistent(False)
         self.on_per_account_checkbutton_toggled(widget, 'restore_last_status')
 
-    def on_prompt_online_status_message_checkbutton_toggled(self, widget):
+    def on_sign_in_status_checkbutton_toggled(self, widget):
         self.on_checkbutton_toggled(widget, 'ask_online_status')
 
-    def on_prompt_offline_status_message_checkbutton_toggled(self, widget):
+    def on_sign_out_status_checkbutton_toggled(self, widget):
         self.on_checkbutton_toggled(widget, 'ask_offline_status')
 
-    def fill_default_msg_treeview(self):
-        model = self._ui.default_msg_treeview.get_model()
-        model.clear()
-        status = []
-        for status_ in app.config.get_per('defaultstatusmsg'):
-            status.append(status_)
-        status.sort()
-        for status_ in status:
-            msg = app.config.get_per('defaultstatusmsg', status_, 'message')
-            msg = helpers.from_one_line(msg)
-            enabled = app.config.get_per('defaultstatusmsg', status_, 'enabled')
-            iter_ = model.append()
-            uf_show = helpers.get_uf_show(status_)
-            model.set(iter_, 0, status_, 1, uf_show, 2, msg, 3, enabled)
-
-    def on_default_msg_cell_edited(self, cell, row, new_text):
-        model = self._ui.default_msg_treeview.get_model()
-        iter_ = model.get_iter_from_string(row)
-        model.set_value(iter_, 2, new_text)
-
-    def default_msg_toggled_cb(self, cell, path):
-        model = self._ui.default_msg_treeview.get_model()
-        model[path][3] = not model[path][3]
-
-    def on_default_msg_treemodel_row_changed(self, model, path, iter_):
-        status = model[iter_][0]
-        message = model[iter_][2]
-        message = helpers.to_one_line(message)
-        app.config.set_per('defaultstatusmsg', status, 'enabled',
-                model[iter_][3])
-        app.config.set_per('defaultstatusmsg', status, 'message', message)
-
-    def save_status_messages(self, model):
-        for msg in app.config.get_per('statusmsg'):
-            app.config.del_per('statusmsg', msg)
-        iter_ = model.get_iter_first()
-        while iter_:
-            val = model[iter_][0]
-            if model[iter_][1]: # We have a preset message
-                if not val: # No title, use message text for title
-                    val = model[iter_][1]
-                app.config.add_per('statusmsg', val)
-                msg = helpers.to_one_line(model[iter_][1])
-                app.config.set_per('statusmsg', val, 'message', msg)
-                i = 2
-                # Store mood / activity
-                for subname in ('activity', 'subactivity', 'activity_text',
-                'mood', 'mood_text'):
-                    val2 = model[iter_][i]
-                    if not val2:
-                        val2 = ''
-                    app.config.set_per('statusmsg', val, subname, val2)
-                    i += 1
-            iter_ = model.iter_next(iter_)
-
-    def on_msg_treemodel_row_changed(self, model, path, iter_):
-        self.save_status_messages(model)
-
-    def on_msg_treemodel_row_deleted(self, model, path):
-        self.save_status_messages(model)
-
-    def fill_msg_treeview(self):
-        self._ui.delete_msg_button.set_sensitive(False)
-        model = self._ui.msg_treeview.get_model()
-        model.clear()
-        preset_status = []
-        for msg_name in app.config.get_per('statusmsg'):
-            if msg_name.startswith('_last_'):
-                continue
-            preset_status.append(msg_name)
-        preset_status.sort()
-        for msg_name in preset_status:
-            msg_text = app.config.get_per('statusmsg', msg_name, 'message')
-            msg_text = helpers.from_one_line(msg_text)
-            activity = app.config.get_per('statusmsg', msg_name, 'activity')
-            subactivity = app.config.get_per('statusmsg', msg_name,
-                'subactivity')
-            activity_text = app.config.get_per('statusmsg', msg_name,
-                'activity_text')
-            mood = app.config.get_per('statusmsg', msg_name, 'mood')
-            mood_text = app.config.get_per('statusmsg', msg_name, 'mood_text')
-            iter_ = model.append()
-            model.set(iter_, 0, msg_name, 1, msg_text, 2, activity, 3,
-                subactivity, 4, activity_text, 5, mood, 6, mood_text)
-
-    def on_msg_cell_edited(self, cell, row, new_text):
-        model = self._ui.msg_treeview.get_model()
-        iter_ = model.get_iter_from_string(row)
-        model.set_value(iter_, 0, new_text)
-
-    def on_msg_treeview_cursor_changed(self, widget, data=None):
-        sel = self._ui.msg_treeview.get_selection()
-        if not sel:
-            return
-        (model, iter_) = sel.get_selected()
-        if not iter_:
-            return
-        self._ui.delete_msg_button.set_sensitive(True)
-        buf = self._ui.msg_textview.get_buffer()
-        msg = model[iter_][1]
-        buf.set_text(msg)
-
-    def on_new_msg_button_clicked(self, widget, data=None):
-        model = self._ui.msg_treeview.get_model()
-        iter_ = model.append()
-        model.set(
-            iter_, 0, _('status message title'), 1,
-            _('status message text'))
-        self._ui.msg_treeview.set_cursor(model.get_path(iter_))
-
-    def on_delete_msg_button_clicked(self, widget, data=None):
-        sel = self._ui.msg_treeview.get_selection()
-        if not sel:
-            return
-        (model, iter_) = sel.get_selected()
-        if not iter_:
-            return
-        buf = self._ui.msg_textview.get_buffer()
-        model.remove(iter_)
-        buf.set_text('')
-        self._ui.delete_msg_button.set_sensitive(False)
-
-    def on_msg_textview_changed(self, widget, data=None):
-        sel = self._ui.msg_treeview.get_selection()
-        if not sel:
-            return
-        (model, iter_) = sel.get_selected()
-        if not iter_:
-            return
-        buf = self._ui.msg_textview.get_buffer()
-        first_iter, end_iter = buf.get_bounds()
-        model.set_value(iter_, 1, buf.get_text(first_iter, end_iter, True))
-
-    def on_msg_treeview_key_press_event(self, widget, event):
-        if event.keyval == Gdk.KEY_Delete:
-            self.on_delete_msg_button_clicked(widget)
+    def on_status_change_checkbutton_toggled(self, widget):
+        self.on_checkbutton_toggled(widget, 'always_ask_for_status_message')
 
     ### Style ###
     @staticmethod
@@ -1052,6 +896,10 @@ class Preferences(Gtk.ApplicationWindow):
     def on_log_show_changes_checkbutton_toggled(self, widget):
         self.on_checkbutton_toggled(widget, 'log_contact_status_changes')
 
+    # Use system’s keyring
+    def _on_use_keyring_toggled(self, widget):
+        self.on_checkbutton_toggled(widget, 'use_keyring')
+
     # Enable debug logging
     def on_enable_logging_toggled(self, widget):
         app.set_debug_mode(widget.get_active())
@@ -1059,6 +907,9 @@ class Preferences(Gtk.ApplicationWindow):
     def _on_debug_folder_clicked(self, _widget):
         open_file(configpaths.get('DEBUG'))
 
+    def _on_update_check_toggled(self, widget):
+        self.on_checkbutton_toggled(widget, 'check_for_update')
+
     def _on_reset_help_clicked(self, widget):
         widget.set_sensitive(False)
         helping_hints = [
