@@ -98,7 +98,6 @@ class SettingsBox(Gtk.ListBox):
             SettingKind.HOSTNAME: CutstomHostnameSetting,
             SettingKind.CHANGEPASSWORD: ChangePasswordSetting,
             SettingKind.COMBO: ComboSetting,
-            SettingKind.CHATSTATE_COMBO: ChatstateComboSetting,
         }
 
         if extend is not None:
@@ -575,15 +574,6 @@ class ComboSetting(GenericSetting):
         pass
 
 
-class ChatstateComboSetting(ComboSetting):
-    def on_value_change(self, combo):
-        self.set_value(combo.get_active_id())
-        if 'muc' in self.value:
-            app.config.del_all_per('rooms', 'send_chatstate')
-        else:
-            app.config.del_all_per('contacts', 'send_chatstate')
-
-
 class ProxyComboSetting(GenericSetting):
 
     __gproperties__ = {
@@ -674,5 +664,6 @@ class ChangePasswordSetting(DialogSetting):
         activatable = False
         if self.account in app.connections:
             con = app.connections[self.account]
-            activatable = con.state.is_available and con.register_supported
+            activatable = (con.state.is_available and
+                           con.get_module('Register').supported)
         self.set_activatable(activatable)
