@@ -33,20 +33,27 @@ import sqlite3
 from enum import IntEnum, unique
 
 import gi
-gi.require_version('Gtk', '3.0')
-gi.require_version('GLib', '2.0')
-gi.require_version('Gdk', '3.0')
-gi.require_version('Gio', '2.0')
+
+try:
+    gi.require_versions({'Gtk': '3.0'})
+except ValueError as error:
+    sys.exit('Missing dependency: %s' % error)
+
+# pylint: disable=C0413
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GLib
 from gi.repository import Gio
+from gi.repository import Pango
 
 from gajim.common import app
-from gajim.common import i18n
 from gajim.common import configpaths
 from gajim.common.i18n import _
+from gajim.common.i18n import ngettext
 from gajim.common.const import StyleAttr
+from gajim.common.const import JIDConstant
+from gajim.common.const import KindConstant
+from gajim.common.const import ShowConstant
 
 def is_standalone():
     # Determine if we are in standalone mode
@@ -81,15 +88,15 @@ if is_standalone():
     configpaths.init()
     app.load_css_config()
 
-from gajim.common.const import JIDConstant, KindConstant
 from gajim.common import helpers
-from gajim.gtk.dialogs import YesNoDialog
 from gajim.gtk.dialogs import ErrorDialog
-from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.dialogs import NewConfirmationDialog
+from gajim.gtk.dialogs import DialogButton
 from gajim.gtk.filechoosers import FileSaveDialog
 from gajim.gtk.util import convert_rgb_to_hex
-from gajim import gtkgui_helpers
-
+from gajim.gtk.util import get_builder
+from gajim.gtk.util import get_app_icon_list
+# pylint: enable=C0413
 
 @unique
 class Column(IntEnum):
@@ -101,31 +108,15 @@ class Column(IntEnum):
 
 class HistoryManager:
     def __init__(self):
-        pixs = []
-        for size in (16, 32, 48, 64, 128):
-            pix = gtkgui_helpers.get_icon_pixmap('org.gajim.Gajim', size)
-            if pix:
-                pixs.append(pix)
-        if pixs:
-            # set the icon to all windows
-            Gtk.Window.set_default_icon_list(pixs)
-
         log_db_path = configpaths.get('LOG_DB')
         if not os.path.exists(log_db_path):
             ErrorDialog(_('Cannot find history logs database'),
-                        '%s does not exist.' % log_db_path)
+                        _('%s does not exist.') % log_db_path)
             sys.exit()
 
-        xml = gtkgui_helpers.get_gtk_builder('history_manager.ui')
-        self.window = xml.get_object('history_manager_window')
-        self.jids_listview = xml.get_object('jids_listview')
-        self.logs_listview = xml.get_object('logs_listview')
-        self.search_results_listview = xml.get_object('search_results_listview')
-        self.search_entry = xml.get_object('search_entry')
-        self.logs_scrolledwindow = xml.get_object('logs_scrolledwindow')
-        self.search_results_scrolledwindow = xml.get_object(
-                'search_results_scrolledwindow')
-        self.welcome_vbox = xml.get_object('welcome_vbox')
+        self._ui = get_builder('history_manager.ui')
+        Gtk.Window.set_default_icon_list(get_app_icon_list(
+            self._ui.history_manager_window))
 
         self.jids_already_in = []  # holds jids that we already have in DB
         self.AT_LEAST_ONE_DELETION_DONE = False
@@ -141,36 +132,36 @@ class HistoryManager:
 
         self._fill_jids_listview()
 
-        self.search_entry.grab_focus()
+        self._ui.search_entry.grab_focus()
 
-        self.window.show_all()
+        self._ui.history_manager_window.show_all()
 
-        xml.connect_signals(self)
+        self._ui.connect_signals(self)
 
     def _init_jids_listview(self):
         self.jids_liststore = Gtk.ListStore(str, str)  # jid, jid_id
-        self.jids_listview.set_model(self.jids_liststore)
-        self.jids_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
+        self._ui.jids_listview.set_model(self.jids_liststore)
+        self._ui.jids_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
         renderer_text = Gtk.CellRendererText()  # holds jid
-        col = Gtk.TreeViewColumn(_('JID'), renderer_text, text=0)
-        self.jids_listview.append_column(col)
+        col = Gtk.TreeViewColumn(_('XMPP Address'), renderer_text, text=0)
+        self._ui.jids_listview.append_column(col)
 
-        self.jids_listview.get_selection().connect('changed',
+        self._ui.jids_listview.get_selection().connect('changed',
                 self.on_jids_listview_selection_changed)
 
     def _init_logs_listview(self):
         # log_line_id(HIDDEN), jid_id(HIDDEN), time, message, subject, nickname
         self.logs_liststore = Gtk.ListStore(str, str, str, str, str, str)
-        self.logs_listview.set_model(self.logs_liststore)
-        self.logs_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
+        self._ui.logs_listview.set_model(self.logs_liststore)
+        self._ui.logs_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
         renderer_text = Gtk.CellRendererText()  # holds time
         col = Gtk.TreeViewColumn(_('Date'), renderer_text, text=Column.UNIXTIME)
         # user can click this header and sort
         col.set_sort_column_id(Column.UNIXTIME)
         col.set_resizable(True)
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds nickname
         col = Gtk.TreeViewColumn(_('Nickname'), renderer_text, text=Column.NICKNAME)
@@ -179,61 +170,69 @@ class HistoryManager:
         col.set_resizable(True)
         col.set_visible(False)
         self.nickname_col_for_logs = col
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds message
+        renderer_text.set_property('width_chars', 60)
+        renderer_text.set_property('ellipsize', Pango.EllipsizeMode.END)
         col = Gtk.TreeViewColumn(_('Message'), renderer_text, markup=Column.MESSAGE)
         # user can click this header and sort
         col.set_sort_column_id(Column.MESSAGE)
         col.set_resizable(True)
         self.message_col_for_logs = col
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds subject
         col = Gtk.TreeViewColumn(_('Subject'), renderer_text, text=Column.SUBJECT)
-        col.set_sort_column_id(Column.SUBJECT)  # user can click this header and sort
+        # user can click this header and sort
+        col.set_sort_column_id(Column.SUBJECT)
         col.set_resizable(True)
         col.set_visible(False)
         self.subject_col_for_logs = col
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
     def _init_search_results_listview(self):
         # log_line_id (HIDDEN), jid, time, message, subject, nickname
         self.search_results_liststore = Gtk.ListStore(int, str, str, str, str,
             str)
-        self.search_results_listview.set_model(self.search_results_liststore)
+        self._ui.search_results_listview.set_model(self.search_results_liststore)
 
         renderer_text = Gtk.CellRendererText()  # holds JID (who said this)
-        col = Gtk.TreeViewColumn(_('JID'), renderer_text, text=1)
-        col.set_sort_column_id(1)  # user can click this header and sort
+        col = Gtk.TreeViewColumn(_('XMPP Address'), renderer_text, text=1)
+        # user can click this header and sort
+        col.set_sort_column_id(1)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds time
         col = Gtk.TreeViewColumn(_('Date'), renderer_text, text=Column.UNIXTIME)
         # user can click this header and sort
         col.set_sort_column_id(Column.UNIXTIME)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds message
+        renderer_text.set_property('width_chars', 60)
+        renderer_text.set_property('ellipsize', Pango.EllipsizeMode.END)
         col = Gtk.TreeViewColumn(_('Message'), renderer_text, text=Column.MESSAGE)
-        col.set_sort_column_id(Column.MESSAGE)  # user can click this header and sort
+        # user can click this header and sort
+        col.set_sort_column_id(Column.MESSAGE)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds subject
         col = Gtk.TreeViewColumn(_('Subject'), renderer_text, text=Column.SUBJECT)
-        col.set_sort_column_id(Column.SUBJECT)  # user can click this header and sort
+        # user can click this header and sort
+        col.set_sort_column_id(Column.SUBJECT)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds nickname
         col = Gtk.TreeViewColumn(_('Nickname'), renderer_text, text=Column.NICKNAME)
         # user can click this header and sort
         col.set_sort_column_id(Column.NICKNAME)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
     def on_history_manager_window_delete_event(self, widget, event):
         if not self.AT_LEAST_ONE_DELETION_DONE:
@@ -241,27 +240,27 @@ class HistoryManager:
                 Gtk.main_quit()
             return
 
-        def on_yes(clicked):
+        def _on_yes():
             self.cur.execute('VACUUM')
             self.con.commit()
             if is_standalone():
                 Gtk.main_quit()
 
-        def on_no():
+        def _on_no():
             if is_standalone():
                 Gtk.main_quit()
 
-        dialog = YesNoDialog(
-            _('Do you want to clean up the database? '
-            '(STRONGLY NOT RECOMMENDED IF GAJIM IS RUNNING)'),
-            _('Normally allocated database size will not be freed, '
-                'it will just become reusable. If you really want to reduce '
-                'database filesize, click YES, else click NO.'
-                '\n\nIn case you click YES, please wait…'),
-            on_response_yes=on_yes, on_response_no=on_no)
-        dialog.set_title(_('Database Cleanup'))
-        button_box = dialog.get_children()[0].get_children()[1]
-        button_box.get_children()[0].grab_focus()
+        NewConfirmationDialog(
+            _('Database Cleanup'),
+            _('Clean up the database?'),
+            _('This is STRONGLY NOT RECOMMENDED IF GAJIM IS RUNNING.\n'
+              'Normally, the allocated database size will not be freed, it '
+              'will just become reusable. This operation may take a while.'),
+            [DialogButton.make('Cancel',
+                               callback=_on_no),
+             DialogButton.make('Remove',
+                               text=_('_Cleanup'),
+                               callback=_on_yes)]).show()
 
     def _fill_jids_listview(self):
         # get those jids that have at least one entry in logs
@@ -274,16 +273,16 @@ class HistoryManager:
             self.jids_liststore.append([row[0], str(row[1])])  # jid, jid_id
 
     def on_jids_listview_selection_changed(self, widget, data=None):
-        liststore, list_of_paths = self.jids_listview.get_selection()\
+        liststore, list_of_paths = self._ui.jids_listview.get_selection()\
                 .get_selected_rows()
 
         self.logs_liststore.clear()
         if not list_of_paths:
             return
 
-        self.welcome_vbox.hide()
-        self.search_results_scrolledwindow.hide()
-        self.logs_scrolledwindow.show()
+        self._ui.welcome_box.hide()
+        self._ui.search_results_scrolledwindow.hide()
+        self._ui.logs_scrolledwindow.show()
 
         list_of_rowrefs = []
         for path in list_of_paths:  # make them treerowrefs (it's needed)
@@ -327,7 +326,7 @@ class HistoryManager:
         If jid is gajim@conf/nkour it's likely a pm one, how we know gajim@conf
         is not a normal guy and nkour is not his resource? We ask if gajim@conf
         is already in jids (with type room jid). This fails if user disables
-        logging for room and only enables for pm (so higly unlikely) and if we
+        logging for room and only enables for pm (so highly unlikely) and if we
         fail we do not go chaos (user will see the first pm as if it was message
         in room's public chat) and after that everything is ok
         """
@@ -372,6 +371,7 @@ class HistoryManager:
             self.nickname_col_for_logs.set_visible(False)
             self.subject_col_for_logs.set_visible(True)
 
+        format_ = helpers.from_one_line(app.config.get('time_stamp'))
         for row in results:
             # exposed in UI (TreeViewColumns) are only
             # time, message, subject, nickname
@@ -380,7 +380,7 @@ class HistoryManager:
             log_line_id, jid_id, time_, kind, message, subject, nickname, \
                 show = row
             try:
-                time_ = time.strftime('%x', time.localtime(float(time_)))
+                time_ = time.strftime(format_, time.localtime(float(time_)))
             except ValueError:
                 pass
             else:
@@ -403,8 +403,8 @@ class HistoryManager:
                         message = ''
                     else:
                         message = ' : ' + message
-                    message = helpers.get_uf_show(app.SHOW_LIST[show]) + \
-                        message
+
+                    message = helpers.get_uf_show(ShowConstant(show)) + message
 
                 message_ = '<span'
                 if color:
@@ -428,6 +428,7 @@ class HistoryManager:
                 ''', (like_sql, like_sql))
 
         results = self.cur.fetchall()
+        format_ = helpers.from_one_line(app.config.get('time_stamp'))
         for row in results:
             # exposed in UI (TreeViewColumns) are only
             # JID, time, message, subject, nickname
@@ -435,7 +436,7 @@ class HistoryManager:
             # log_line_id, jid (from jid_id), time, message, subject, nickname
             log_line_id, jid_id, time_, message, subject, nickname = row
             try:
-                time_ = time.strftime('%x', time.localtime(float(time_)))
+                time_ = time.strftime(format_, time.localtime(float(time_)))
             except ValueError:
                 pass
             else:
@@ -445,32 +446,31 @@ class HistoryManager:
                         message, subject, nickname))
 
     def on_logs_listview_key_press_event(self, widget, event):
-        liststore, list_of_paths = self.logs_listview.get_selection()\
+        liststore, list_of_paths = self._ui.logs_listview.get_selection()\
                 .get_selected_rows()
         if event.keyval == Gdk.KEY_Delete:
             self._delete_logs(liststore, list_of_paths)
 
     def on_listview_button_press_event(self, widget, event):
         if event.button == 3:  # right click
-            xml = gtkgui_helpers.get_gtk_builder('history_manager.ui',
-                'context_menu')
+            _ui = get_builder('history_manager.ui', ['context_menu'])
             if Gtk.Buildable.get_name(widget) != 'jids_listview':
-                xml.get_object('export_menuitem').hide()
-            xml.get_object('delete_menuitem').connect('activate',
+                _ui.export_menuitem.hide()
+            _ui.delete_menuitem.connect('activate',
                     self.on_delete_menuitem_activate, widget)
 
-            xml.connect_signals(self)
-            xml.get_object('context_menu').popup(None, None, None, None,
+            _ui.connect_signals(self)
+            _ui.context_menu.popup(None, None, None, None,
                     event.button, event.time)
             return True
 
     def on_export_menuitem_activate(self, widget):
         FileSaveDialog(self._on_export,
-                       transient_for=self.window,
+                       transient_for=self._ui.history_manager_window,
                        modal=True)
 
     def _on_export(self, filename):
-        liststore, list_of_paths = self.jids_listview.get_selection()\
+        liststore, list_of_paths = self._ui.jids_listview.get_selection()\
                 .get_selected_rows()
         self._export_jids_logs_to_file(liststore, list_of_paths, filename)
 
@@ -485,7 +485,7 @@ class HistoryManager:
             return
 
     def on_jids_listview_key_press_event(self, widget, event):
-        liststore, list_of_paths = self.jids_listview.get_selection()\
+        liststore, list_of_paths = self._ui.jids_listview.get_selection()\
                 .get_selected_rows()
         if event.keyval == Gdk.KEY_Delete:
             self._delete_jid_logs(liststore, list_of_paths)
@@ -544,7 +544,7 @@ class HistoryManager:
         if paths_len == 0:  # nothing is selected
             return
 
-        def on_ok(liststore, list_of_paths):
+        def on_ok():
             # delete all rows from db that match jid_id
             list_of_rowrefs = []
             for path in list_of_paths:  # make them treerowrefs (it's needed)
@@ -572,28 +572,24 @@ class HistoryManager:
 
             self.AT_LEAST_ONE_DELETION_DONE = True
 
-        if paths_len == 1:
-            jid_id = '<i>%s</i>' % liststore[list_of_paths[0]][0]
-            pri_text = _('Do you wish to delete all correspondence with %(jid)s?') \
-                % {'jid': jid_id}
-        else:
-            pri_text = _(
-                'Do you wish to delete all correspondence with the selected contacts?')
-        dialog = ConfirmationDialog('',
-            _('This can not be undone.'), on_response_ok=(on_ok,
-            liststore, list_of_paths))
-        dialog.set_title(_('Deletion Confirmation'))
-        dialog.set_markup(pri_text)
-        ok_button = dialog.get_children()[0].get_children()[1].get_children()[0]
-        ok_button.grab_focus()
-        dialog.set_transient_for(self.window)
+        NewConfirmationDialog(
+            _('Delete'),
+            ngettext('Delete Conversation', 'Delete Conversations', paths_len),
+            ngettext('Do you want to permanently delete this '
+                     'conversation with <b>%s</b>?',
+                     'Do you want to permanently delete these conversations?',
+                     paths_len, liststore[list_of_paths[0]][0]),
+            [DialogButton.make('Cancel'),
+             DialogButton.make('Delete',
+                               callback=on_ok)],
+            transient_for=self._ui.history_manager_window).show()
 
     def _delete_logs(self, liststore, list_of_paths):
         paths_len = len(list_of_paths)
         if paths_len == 0:  # nothing is selected
             return
 
-        def on_ok(liststore, list_of_paths):
+        def on_ok():
             # delete rows from db that match log_line_id
             list_of_rowrefs = []
             for path in list_of_paths:  # make them treerowrefs (it's needed)
@@ -615,25 +611,25 @@ class HistoryManager:
 
             self.AT_LEAST_ONE_DELETION_DONE = True
 
-        pri_text = i18n.ngettext(
-            'Do you really want to delete the selected message?',
-            'Do you really want to delete the selected messages?', paths_len)
-        dialog = ConfirmationDialog(pri_text,
-            _('This is an irreversible operation.'), on_response_ok=(on_ok,
-            liststore, list_of_paths))
-        dialog.set_title(_('Deletion Confirmation'))
-        ok_button = dialog.get_children()[0].get_children()[1].get_children()[0]
-        ok_button.grab_focus()
-        dialog.set_transient_for(self.window)
+        NewConfirmationDialog(
+            _('Delete'),
+            ngettext('Delete Message', 'Delete Messages', paths_len),
+            ngettext('Do you want to permanently delete this message?',
+                     'Do you want to permanently delete these messages?',
+                     paths_len),
+            [DialogButton.make('Cancel'),
+             DialogButton.make('Delete',
+                               callback=on_ok)],
+            transient_for=self._ui.history_manager_window).show()
 
     def on_search_db_button_clicked(self, widget):
-        text = self.search_entry.get_text()
+        text = self._ui.search_entry.get_text()
         if not text:
             return
 
-        self.welcome_vbox.hide()
-        self.logs_scrolledwindow.hide()
-        self.search_results_scrolledwindow.show()
+        self._ui.welcome_box.hide()
+        self._ui.logs_scrolledwindow.hide()
+        self._ui.search_results_scrolledwindow.show()
 
         self._fill_search_results_listview(text)
 
@@ -656,7 +652,7 @@ class HistoryManager:
             return
 
         path = self.jids_liststore.get_path(iter_)
-        self.jids_listview.set_cursor(path)
+        self._ui.jids_listview.set_cursor(path)
 
         iter_ = self.logs_liststore.get_iter_first()
         while iter_:
@@ -666,8 +662,8 @@ class HistoryManager:
             iter_ = self.logs_liststore.iter_next(iter_)
 
         path = self.logs_liststore.get_path(iter_)
-        self.logs_listview.scroll_to_cell(path)
-        self.logs_listview.get_selection().select_path(path)
+        self._ui.logs_listview.scroll_to_cell(path)
+        self._ui.logs_listview.get_selection().select_path(path)
 
 
 def main():
