@@ -32,6 +32,9 @@ import binascii
 from gi.repository import Gtk
 from gi.repository import GLib
 from gi.repository import Gdk
+from nbxmpp.structs import AnnotationNote
+from nbxmpp.util import is_error_result
+from nbxmpp.protocol import JID
 
 from gajim import gtkgui_helpers
 from gajim.common import helpers
@@ -41,18 +44,22 @@ from gajim.common import configpaths
 from gajim.common.i18n import Q_
 from gajim.common.i18n import _
 from gajim.common.const import AvatarSize
+from gajim.common.nec import EventHelper
+
+from gajim.gtk.util import get_builder
 
 # log = logging.getLogger('gajim.vcard')
 
 
-class VcardWindow:
+class VcardWindow(EventHelper):
     """
     Class for contact's information window
     """
 
     def __init__(self, contact, account, gc_contact=None):
+        EventHelper.__init__(self)
         # the contact variable is the jid if vcard is true
-        self.xml = gtkgui_helpers.get_gtk_builder('vcard_information_window.ui')
+        self.xml = get_builder('vcard_information_window.ui')
         self.window = self.xml.get_object('vcard_information_window')
         self.progressbar = self.xml.get_object('progressbar')
 
@@ -98,17 +105,16 @@ class VcardWindow:
         self.update_progressbar_timeout_id = GLib.timeout_add(self.update_intervall,
             self.update_progressbar)
 
-        app.ged.register_event_handler('version-result-received', ged.GUI1,
-            self.set_os_info)
-        app.ged.register_event_handler('time-result-received', ged.GUI1,
-            self.set_entity_time)
+        self.register_events([
+            ('time-result-received', ged.GUI1, self.set_entity_time),
+        ])
 
         self.fill_jabber_page()
         con = app.connections[self.account]
-        annotations = con.get_module('Annotations').annotations
-        if self.contact.jid in annotations:
+        note = con.get_module('Annotations').get_note(self.contact.jid)
+        if note is not None:
             buffer_ = self.xml.get_object('textview_annotation').get_buffer()
-            buffer_.set_text(annotations[self.contact.jid])
+            buffer_.set_text(note.data)
 
         for widget_name in ('URL_label',
                             'EMAIL_WORK_USERID_label',
@@ -137,16 +143,14 @@ class VcardWindow:
         del app.interface.instances[self.account]['infos'][self.contact.jid]
         buffer_ = self.xml.get_object('textview_annotation').get_buffer()
         new_annotation = buffer_.get_text(buffer_.get_start_iter(),
-                buffer_.get_end_iter(), True)
+                                          buffer_.get_end_iter(),
+                                          True)
         con = app.connections[self.account]
-        annotations = con.get_module('Annotations').annotations
-        if new_annotation != annotations.get(self.contact.jid, ''):
-            annotations[self.contact.jid] = new_annotation
-            con.get_module('Annotations').store_annotations()
-        app.ged.remove_event_handler('version-result-received', ged.GUI1,
-            self.set_os_info)
-        app.ged.remove_event_handler('time-result-received', ged.GUI1,
-            self.set_entity_time)
+        note = con.get_module('Annotations').get_note(self.contact.jid)
+        if note is None or new_annotation != note.data:
+            new_note = AnnotationNote(jid=self.contact.jid, data=new_annotation)
+            con.get_module('Annotations').set_note(new_note)
+        self.unregister_events()
 
     def on_vcard_information_window_key_press_event(self, widget, event):
         if event.keyval == Gdk.KEY_Escape:
@@ -155,31 +159,6 @@ class VcardWindow:
     def on_information_notebook_switch_page(self, widget, page, page_num):
         GLib.idle_add(self.xml.get_object('close_button').grab_focus)
 
-    def on_PHOTO_eventbox_button_press_event(self, widget, event):
-        """
-        If right-clicked, show popup
-        """
-        if event.button == 3: # right click
-            menu = Gtk.Menu()
-            menuitem = Gtk.MenuItem.new_with_mnemonic(_('Save _As'))
-            if self.gc_contact:
-                sha = self.gc_contact.avatar_sha
-                name = self.gc_contact.get_shown_name()
-            else:
-                sha = app.contacts.get_avatar_sha(
-                    self.account, self.contact.jid)
-                name = self.contact.get_shown_name()
-            if sha is None:
-                sha = self.avatar
-            menuitem.connect('activate',
-                gtkgui_helpers.on_avatar_save_as_menuitem_activate, sha, name)
-            menu.append(menuitem)
-            menu.connect('selection-done', lambda w: w.destroy())
-            # show the menu
-            menu.show_all()
-            menu.attach_to_widget(widget, None)
-            menu.popup(None, None, None, None, event.button, event.time)
-
     def set_value(self, entry_name, value):
         try:
             widget = self.xml.get_object(entry_name)
@@ -267,34 +246,27 @@ class VcardWindow:
         self.clear_values()
         self._set_values(vcard, jid)
 
-    def set_os_info(self, obj):
-        if obj.conn.name != self.account:
-            return
+    def set_os_info(self, result, jid):
         if self.xml.get_object('information_notebook').get_n_pages() < 5:
             return
-        if self.gc_contact:
-            if obj.jid != self.contact.jid:
-                return
-        elif obj.jid.getStripped() != self.contact.jid:
-            return
+
+        error = is_error_result(result)
         i = 0
         client = ''
         os_info = ''
         while i in self.os_info:
-            if self.os_info[i]['resource'] == obj.jid.getResource():
-                if obj.client_info:
-                    self.os_info[i]['client'] = obj.client_info
+            if self.os_info[i]['resource'] == JID(jid).getResource():
+                if not error:
+                    self.os_info[i]['client'] = '%s %s' % (result.name,
+                                                           result.version)
                 else:
                     self.os_info[i]['client'] = Q_('?Client:Unknown')
-                if obj.os_info:
-                    self.os_info[i]['os'] = obj.os_info
+
+                if not error and result.os is not None:
+                    self.os_info[i]['os'] = result.os
                 else:
                     self.os_info[i]['os'] = Q_('?OS:Unknown')
-            else:
-                if not self.os_info[i]['client']:
-                    self.os_info[i]['client'] = Q_('?Client:Unknown')
-                if not self.os_info[i]['os']:
-                    self.os_info[i]['os'] = Q_('?OS:Unknown')
+
             if i > 0:
                 client += '\n'
                 os_info += '\n'
@@ -421,12 +393,16 @@ class VcardWindow:
             self.os_info_arrived = True
         else: # Request os info if contact is connected
             if self.gc_contact:
-                j, r = app.get_room_and_nick_from_fjid(self.real_jid)
-                GLib.idle_add(con.get_module('SoftwareVersion').request_os_info,
-                              j, r)
+                con.get_module('SoftwareVersion').request_software_version(
+                    self.real_jid,
+                    callback=self.set_os_info,
+                    user_data=self.real_jid)
             else:
-                GLib.idle_add(con.get_module('SoftwareVersion').request_os_info,
-                              self.contact.jid, self.contact.resource)
+                jid = self.contact.get_full_jid()
+                con.get_module('SoftwareVersion').request_software_version(
+                    jid,
+                    callback=self.set_os_info,
+                    user_data=jid)
 
         # do not wait for entity_time if contact is not connected or has error
         # additional check for observer is needed, as show is offline for him
@@ -455,8 +431,9 @@ class VcardWindow:
                     uf_resources += '\n' + c.resource + \
                             _(' resource with priority ') + str(c.priority)
                     if c.show not in ('offline', 'error'):
-                        GLib.idle_add(con.get_module('SoftwareVersion').request_os_info,
-                                      c.jid, c.resource)
+                        jid = c.get_full_jid()
+                        con.get_module('SoftwareVersion').request_software_version(
+                            jid, callback=self.set_os_info, user_data=jid)
                         GLib.idle_add(con.get_module('EntityTime').request_entity_time,
                                       c.jid, c.resource)
                     self.os_info[i] = {'resource': c.resource, 'client': '',
@@ -487,7 +464,7 @@ class VcardWindow:
 class ZeroconfVcardWindow:
     def __init__(self, contact, account, is_fake=False):
         # the contact variable is the jid if vcard is true
-        self.xml = gtkgui_helpers.get_gtk_builder('zeroconf_information_window.ui')
+        self.xml = get_builder('zeroconf_information_window.ui')
         self.window = self.xml.get_object('zeroconf_information_window')
 
         self.contact = contact
@@ -507,23 +484,6 @@ class ZeroconfVcardWindow:
         if event.keyval == Gdk.KEY_Escape:
             self.window.destroy()
 
-    def on_PHOTO_eventbox_button_press_event(self, widget, event):
-        """
-        If right-clicked, show popup
-        """
-        if event.button == 3: # right click
-            menu = Gtk.Menu()
-            menuitem = Gtk.MenuItem.new_with_mnemonic(_('Save _As'))
-            menuitem.connect('activate',
-                    gtkgui_helpers.on_avatar_save_as_menuitem_activate,
-                    self.contact.avatar_sha, self.contact.get_shown_name())
-            menu.append(menuitem)
-            menu.connect('selection-done', lambda w: w.destroy())
-            # show the menu
-            menu.show_all()
-            menu.attach_to_widget(widget, None)
-            menu.popup(None, None, None, None, event.button, event.time)
-
     def set_value(self, entry_name, value):
         try:
             if value and entry_name == 'URL_label':
